@@ -379,8 +379,8 @@ func TestLintWithCustomCapabilitiesAndUnmetRequirement(t *testing.T) {
 		expectStdout(equals(
 			"1 file linted. No violations found. 3 rules skipped:\n" +
 				"- custom-has-key-construct: Missing capability for built-in function `object.keys`\n" +
-				"- use-strings-count: Missing capability for built-in function `strings.count`\n" +
-				"- use-rego-v1: Missing capability for `import rego.v1`\n\n",
+				"- use-rego-v1: Missing capability for `import rego.v1`\n" +
+				"- use-strings-count: Missing capability for built-in function `strings.count`\n\n",
 		)).
 		verify(t)
 }
@@ -390,8 +390,8 @@ func TestLintWithCustomCapabilitiesAndUnmetRequirementMultipleFiles(t *testing.T
 		expectStdout(equals(
 			"2 files linted. No violations found. 3 rules skipped:\n" +
 				"- custom-has-key-construct: Missing capability for built-in function `object.keys`\n" +
-				"- use-strings-count: Missing capability for built-in function `strings.count`\n" +
-				"- use-rego-v1: Missing capability for `import rego.v1`\n\n",
+				"- use-rego-v1: Missing capability for `import rego.v1`\n" +
+				"- use-strings-count: Missing capability for built-in function `strings.count`\n\n",
 		)).
 		verify(t)
 }
@@ -479,16 +479,16 @@ foo/main_test.rego -> wow/main_test.rego:
 - opa-fmt
 
 
-In project root: %[1]s/v0
+In project root: %[2]s
 main.rego:
 - use-rego-v1
 - no-whitespace-comment
 
-In project root: %[1]s/v1
+In project root: %[3]s
 main.rego:
 - no-whitespace-comment
 - opa-fmt
-`, td)
+`, td, filepath.Join(td, "v0"), filepath.Join(td, "v1"))
 
 	expectedState := map[string]string{
 		"foo/foo.rego": `package foo
@@ -499,9 +499,9 @@ allow if {
 	input.admin
 }
 `,
-		"wow/foo-bar/baz/main.rego": `package wow["foo-bar"].baz
+		filepath.FromSlash("wow/foo-bar/baz/main.rego"): `package wow["foo-bar"].baz
 `,
-		"wow/foo-bar/baz/main_test.rego": `package wow["foo-bar"].baz_test
+		filepath.FromSlash("wow/foo-bar/baz/main_test.rego"): `package wow["foo-bar"].baz_test
 
 test_allow := true
 `,
@@ -542,12 +542,12 @@ allow := true
 
 func TestFixWithConflicts(t *testing.T) {
 	initialState := map[string]string{
-		".regal/config.yaml":   "",              // needed to find the root in the right place
-		"foo/foo.rego":         "package foo\n", // this file is in the correct location
-		"quz/foo.rego":         "package foo\n", // should be at foo/foo.rego, but that file already exists
-		"foo/bar.rego":         "package bar\n", // should be at bar/bar.rego, but they cannot all be moved there
-		"baz/bar.rego":         "package bar\n", // should be at bar/bar.rego, but they cannot all be moved there
-		"bax/foo/wow/bar.rego": "package bar\n", // should be at bar/bar.rego, but they cannot all be moved there
+		filepath.FromSlash(".regal/config.yaml"):   "",              // needed to find the root in the right place
+		filepath.FromSlash("foo/foo.rego"):         "package foo\n", // this file is in the correct location
+		filepath.FromSlash("quz/foo.rego"):         "package foo\n", // should be at foo/foo.rego, but that file already exists
+		filepath.FromSlash("foo/bar.rego"):         "package bar\n", // should be at bar/bar.rego, but they cannot all be moved there
+		filepath.FromSlash("baz/bar.rego"):         "package bar\n", // should be at bar/bar.rego, but they cannot all be moved there
+		filepath.FromSlash("bax/foo/wow/bar.rego"): "package bar\n", // should be at bar/bar.rego, but they cannot all be moved there
 	}
 
 	td := testutil.TempDirectoryOf(t, initialState)
