@@ -25,6 +25,11 @@ import (
 	"github.com/open-policy-agent/regal/pkg/roast/encoding"
 )
 
+var (
+	OPACapabilities = ast.CapabilitiesForThisVersion()
+	Capabilities    = sync.OnceValue(capabilities)
+)
+
 type readWriteCloser struct {
 	in  io.ReadCloser
 	out io.WriteCloser
@@ -65,6 +70,7 @@ func LoadRegalBundleFS(fs fs.FS) (*bundle.Bundle, error) {
 		WithSkipBundleVerification(true).
 		WithProcessAnnotations(true).
 		WithLazyLoadingMode(false). // NB(sr): This is OPA's default, unless when using bundle plugins
+		WithRegoVersion(ast.RegoV1).
 		WithBundleName("regal").
 		Read()
 	if err != nil {
@@ -80,6 +86,7 @@ func LoadRegalBundlePath(path string) (*bundle.Bundle, error) {
 	if err != nil {
 		return nil, fmt.Errorf("failed to open root: %w", err)
 	}
+	defer CloseIgnore(root)
 
 	return LoadRegalBundleFS(root.FS())
 }
@@ -103,10 +110,10 @@ func ToMap(a any) map[string]any {
 	return r
 }
 
-// CloseFileIgnore closes file ignoring errors, mainly for deferred cleanup.
-func CloseFileIgnore(file *os.File) {
-	if file != nil {
-		_ = file.Close()
+// CloseIgnore closes handle ignoring errors, mainly for deferred cleanup.
+func CloseIgnore(handle io.Closer) {
+	if handle != nil {
+		_ = handle.Close()
 	}
 }
 
@@ -137,6 +144,20 @@ func Exists(path string) bool {
 	return err == nil
 }
 
+// WithOpen opens the file at path, defers close, and invokes f with the *os.File.
+// It returns the result and preserves the original error semantics from the previous location.
+func WithOpen[T any](path string, f func(*os.File) (T, error)) (T, error) {
+	file, err := os.Open(path)
+	if err != nil {
+		var zero T
+
+		return zero, fmt.Errorf("failed to open file '%s': %w", path, err)
+	}
+	defer file.Close()
+
+	return f(file)
+}
+
 // WithCreateRecursive creates a file at the given path, ensuring that all parent directories
 // are created recursively. It then calls the provided function with the created file as an argument
 // before closing the file.
@@ -149,13 +170,13 @@ func WithCreateRecursive(path string, fn func(f *os.File) error) error {
 	if err != nil {
 		return err
 	}
-	defer file.Close()
+	defer CloseIgnore(file)
 
 	return fn(file)
 }
 
-// FindInputPath consults the filesystem and returns the input.json or input.yaml closes to the
-// file provided as arguments.
+// FindInputPath consults the filesystem and returns the location of the input.json
+// or input.yaml closest to the file provided.
 func FindInputPath(file string, workspacePath string) string {
 	relative := strings.TrimPrefix(file, workspacePath)
 	components := strings.Split(filepath.Dir(relative), string(os.PathSeparator))
@@ -256,7 +277,8 @@ func DirCleanUpPaths(target string, preserve []string) ([]string, error) {
 			preserveDirs.Add(p)
 
 			p = filepath.Dir(p)
-			if p == "." || p == "/" || preserveDirs.Contains(p) {
+			if p == "." || p == "/" || p == string(filepath.Separator) ||
+				p == filepath.VolumeName(p) || preserveDirs.Contains(p) {
 				break
 			}
 		}
@@ -310,12 +332,6 @@ func DirCleanUpPaths(target string, preserve []string) ([]string, error) {
 	return dirs, nil
 }
 
-// TODO: This is currently done in too many places
-
-var OPACapabilities = ast.CapabilitiesForThisVersion()
-
-var Capabilities = sync.OnceValue(capabilities)
-
 func capabilities() *ast.Capabilities {
 	cpy := *OPACapabilities
 	cpy.Builtins = append(cpy.Builtins,
