@@ -1,13 +1,14 @@
 package bundles
 
 import (
-	"os"
+	"io"
+	"maps"
 	"path/filepath"
-	"reflect"
 	"slices"
 	"testing"
 
-	"github.com/styrainc/regal/internal/testutil"
+	"github.com/open-policy-agent/regal/internal/lsp/log"
+	"github.com/open-policy-agent/regal/internal/testutil"
 )
 
 func TestRefresh(t *testing.T) {
@@ -18,13 +19,10 @@ func TestRefresh(t *testing.T) {
 		"foo/data.json": `{"foo": "bar"}`,
 	})
 
-	c := NewCache(&CacheOptions{WorkspacePath: workspacePath})
+	c := NewCache(workspacePath, log.NewLogger(log.LevelOff, io.Discard))
 
 	// perform the first load of the bundles
-	refreshedBundles, err := c.Refresh()
-	if err != nil {
-		t.Fatalf("failed to refresh cache: %v", err)
-	}
+	refreshedBundles := testutil.Must(c.Refresh())(t)
 
 	if !slices.Equal(refreshedBundles, []string{"foo"}) {
 		t.Fatalf("unexpected refreshed bundles: %v", refreshedBundles)
@@ -34,12 +32,8 @@ func TestRefresh(t *testing.T) {
 		t.Fatalf("unexpected number of bundles: %d", len(c.List()))
 	}
 
-	fooBundle, ok := c.Get("foo")
-	if !ok {
-		t.Fatalf("failed to get bundle foo")
-	}
-
-	if !reflect.DeepEqual(fooBundle.Data, map[string]any{"foo": "bar"}) {
+	fooBundle := testutil.MustBeOK(c.Get("foo"))(t)
+	if !maps.Equal(fooBundle.Data, map[string]any{"foo": "bar"}) {
 		t.Fatalf("unexpected bundle data: %v", fooBundle.Data)
 	}
 
@@ -47,15 +41,12 @@ func TestRefresh(t *testing.T) {
 		t.Fatalf("unexpected bundle roots: %v", fooBundle.Manifest.Roots)
 	}
 
-	if !reflect.DeepEqual(*fooBundle.Manifest.Roots, []string{"foo"}) {
+	if !slices.Equal(*fooBundle.Manifest.Roots, []string{"foo"}) {
 		t.Fatalf("unexpected bundle roots: %v", *fooBundle.Manifest.Roots)
 	}
 
 	// perform the second load of the bundles, after no changes on disk
-	refreshedBundles, err = c.Refresh()
-	if err != nil {
-		t.Fatalf("failed to refresh cache: %v", err)
-	}
+	refreshedBundles = testutil.Must(c.Refresh())(t)
 
 	if !slices.Equal(refreshedBundles, []string{}) {
 		t.Fatalf("unexpected refreshed bundles: %v", refreshedBundles)
@@ -65,11 +56,7 @@ func TestRefresh(t *testing.T) {
 	testutil.MustWriteFile(t, filepath.Join(workspacePath, "foo", "foo.rego"), []byte(`package wow`))
 
 	// perform the third load of the bundles, after adding a new unrelated file
-	refreshedBundles, err = c.Refresh()
-	if err != nil {
-		t.Fatalf("failed to refresh cache: %v", err)
-	}
-
+	refreshedBundles = testutil.Must(c.Refresh())(t)
 	if !slices.Equal(refreshedBundles, []string{}) {
 		t.Fatalf("unexpected refreshed bundles: %v", refreshedBundles)
 	}
@@ -77,21 +64,13 @@ func TestRefresh(t *testing.T) {
 	// update the data in the bundle
 	testutil.MustWriteFile(t, filepath.Join(workspacePath, "foo", "data.json"), []byte(`{"foo": "baz"}`))
 
-	refreshedBundles, err = c.Refresh()
-	if err != nil {
-		t.Fatalf("failed to refresh cache: %v", err)
-	}
-
+	refreshedBundles = testutil.Must(c.Refresh())(t)
 	if !slices.Equal(refreshedBundles, []string{"foo"}) {
 		t.Fatalf("unexpected refreshed bundles: %v", refreshedBundles)
 	}
 
-	fooBundle, ok = c.Get("foo")
-	if !ok {
-		t.Fatalf("failed to get bundle foo")
-	}
-
-	if !reflect.DeepEqual(fooBundle.Data, map[string]any{"foo": "baz"}) {
+	fooBundle = testutil.MustBeOK(c.Get("foo"))(t)
+	if !maps.Equal(fooBundle.Data, map[string]any{"foo": "baz"}) {
 		t.Fatalf("unexpected bundle data: %v", fooBundle.Data)
 	}
 
@@ -100,33 +79,20 @@ func TestRefresh(t *testing.T) {
 	testutil.MustWriteFile(t, filepath.Join(workspacePath, "bar", ".manifest"), []byte(`{"roots":["bar"]}`))
 	testutil.MustWriteFile(t, filepath.Join(workspacePath, "bar", "data.json"), []byte(`{"bar": true}`))
 
-	refreshedBundles, err = c.Refresh()
-	if err != nil {
-		t.Fatalf("failed to refresh cache: %v", err)
-	}
-
+	refreshedBundles = testutil.Must(c.Refresh())(t)
 	if !slices.Equal(refreshedBundles, []string{"bar"}) {
 		t.Fatalf("unexpected refreshed bundles: %v", refreshedBundles)
 	}
 
-	barBundle, ok := c.Get("bar")
-	if !ok {
-		t.Fatalf("failed to get bundle foo")
-	}
-
-	if !reflect.DeepEqual(barBundle.Data, map[string]any{"bar": true}) {
+	barBundle := testutil.MustBeOK(c.Get("bar"))(t)
+	if !maps.Equal(barBundle.Data, map[string]any{"bar": true}) {
 		t.Fatalf("unexpected bundle data: %v", fooBundle.Data)
 	}
 
 	// remove the foo bundle
-	if err = os.RemoveAll(filepath.Join(workspacePath, "foo")); err != nil {
-		t.Fatalf("failed to remove foo bundle: %v", err)
-	}
-
-	if _, err = c.Refresh(); err != nil {
-		t.Fatalf("failed to refresh cache: %v", err)
-	}
+	testutil.MustRemoveAll(t, workspacePath, "foo")
 
+	_ = testutil.Must(c.Refresh())(t)
 	if !slices.Equal(c.List(), []string{"bar"}) {
 		t.Fatalf("unexpected bundle list: %v", c.List())
 	}
