@@ -13,6 +13,7 @@ import (
 
 	rbundle "github.com/open-policy-agent/regal/bundle"
 	rquery "github.com/open-policy-agent/regal/internal/lsp/rego/query"
+	"github.com/open-policy-agent/regal/internal/lsp/uri"
 	"github.com/open-policy-agent/regal/internal/util"
 	"github.com/open-policy-agent/regal/pkg/builtins"
 	"github.com/open-policy-agent/regal/pkg/config"
@@ -96,8 +97,7 @@ func prepareRegoArgs(
 	cfg *config.Config,
 ) []func(*rego.Rego) {
 	bundleArgs := make([]func(*rego.Rego), 0, len(bundles))
-	// this copy is expensive, but I don't think we can avoid it
-	for key, b := range bundles { //nolint:gocritic
+	for key, b := range bundles { //nolint:gocritic // expensive copy, but I don't think we can avoid it
 		bundleArgs = append(bundleArgs, rego.ParsedBundle(key, &b))
 	}
 
@@ -141,7 +141,7 @@ func (l *LanguageServer) assembleEvalBundles() map[string]bundle.Bundle {
 	hasCustomRules := false
 
 	for fileURI, module := range modules {
-		moduleFiles = append(moduleFiles, bundle.ModuleFile{URL: fileURI, Parsed: module, Path: l.toPath(fileURI)})
+		moduleFiles = append(moduleFiles, bundle.ModuleFile{URL: fileURI, Parsed: module, Path: uri.ToPath(fileURI)})
 		hasCustomRules = hasCustomRules || strings.Contains(module.Package.Path.String(), "custom.regal.rules")
 	}
 
@@ -169,7 +169,7 @@ func (l *LanguageServer) assembleEvalBundles() map[string]bundle.Bundle {
 	if hasCustomRules {
 		// If someone evaluates a custom Regal rule, provide them the Regal bundle
 		// in order to make all Regal functions available
-		allBundles["regal"] = *rbundle.LoadedBundle()
+		allBundles["regal"] = *rbundle.Loaded()
 	}
 
 	return allBundles
