@@ -5,15 +5,16 @@ import (
 	"os"
 	"path/filepath"
 	"slices"
-	"strings"
 	"testing"
 
 	"github.com/google/go-cmp/cmp"
 
 	rio "github.com/open-policy-agent/regal/internal/io"
 	"github.com/open-policy-agent/regal/internal/lsp/log"
+	"github.com/open-policy-agent/regal/internal/lsp/uri"
 	rparse "github.com/open-policy-agent/regal/internal/parse"
 	"github.com/open-policy-agent/regal/internal/testutil"
+	"github.com/open-policy-agent/regal/internal/util"
 )
 
 func TestEvalWorkspacePath(t *testing.T) {
@@ -40,12 +41,12 @@ func TestEvalWorkspacePath(t *testing.T) {
 	}
 	`
 
-	policy1URI := ls.workspaceRootURI + "/policy1.rego"
-	policy1RelativeFileName := strings.TrimPrefix(policy1URI, ls.workspaceRootURI+"/")
+	policy1URI := uri.FromRelativePath(ls.client.Identifier, "policy1.rego", ls.workspaceRootURI)
+	policy1RelativeFileName := uri.ToRelativePath(policy1URI, ls.workspaceRootURI)
 	module1 := testutil.Must(rparse.ModuleWithOpts(policy1RelativeFileName, policy1, rparse.ParserOptions()))(t)
 
-	policy2URI := ls.workspaceRootURI + "/policy2.rego"
-	policy2RelativeFileName := strings.TrimPrefix(policy2URI, ls.workspaceRootURI+"/")
+	policy2URI := uri.FromRelativePath(ls.client.Identifier, "policy2.rego", ls.workspaceRootURI)
+	policy2RelativeFileName := uri.ToRelativePath(policy2URI, ls.workspaceRootURI)
 	module2 := testutil.Must(rparse.ModuleWithOpts(policy2RelativeFileName, policy2, rparse.ParserOptions()))(t)
 
 	ls.cache.SetFileContents(policy1URI, policy1)
@@ -73,16 +74,9 @@ func TestEvalWorkspacePathInternalData(t *testing.T) {
 
 	res := testutil.Must(ls.EvalInWorkspace(t.Context(), "object.keys(data.internal)", map[string]any{}))(t)
 	val := testutil.MustBe[[]any](t, res.Value)
+	act := util.Sorted(testutil.Must(util.AnySliceTo[string](val))(t))
 
-	act := make([]string, 0, len(val))
-	for _, v := range val {
-		act = append(act, testutil.MustBe[string](t, v))
-	}
-
-	slices.Sort(act)
-
-	exp := []string{"capabilities", "combined_config"}
-	if !slices.Equal(exp, act) {
+	if exp := []string{"capabilities", "combined_config"}; !slices.Equal(exp, act) {
 		t.Fatalf("expected %v, got %v", exp, act)
 	}
 }
@@ -106,16 +100,19 @@ func TestFindInputPath(t *testing.T) {
 				t.Fatalf("did not expect to find input.%s", tc.fileExt)
 			}
 
-			createWithContent(t, tmpDir+"/workspace/foo/bar/input."+tc.fileExt, tc.fileContent)
+			inputPath := filepath.Join(workspacePath, "foo", "bar", "input."+tc.fileExt)
+			createWithContent(t, inputPath, tc.fileContent)
 
-			if path, exp := rio.FindInputPath(file, workspacePath), workspacePath+"/foo/bar/input."+tc.fileExt; path != exp {
+			if path, exp := rio.FindInputPath(file, workspacePath), inputPath; path != exp {
 				t.Errorf(`expected input at %s, got %s`, exp, path)
 			}
 
-			testutil.MustRemove(t, tmpDir+"/workspace/foo/bar/input."+tc.fileExt)
-			createWithContent(t, tmpDir+"/workspace/input."+tc.fileExt, tc.fileContent)
+			testutil.MustRemove(t, inputPath)
 
-			if path, exp := rio.FindInputPath(file, workspacePath), workspacePath+"/input."+tc.fileExt; path != exp {
+			workspaceInputPath := filepath.Join(workspacePath, "input."+tc.fileExt)
+			createWithContent(t, workspaceInputPath, tc.fileContent)
+
+			if path, exp := rio.FindInputPath(file, workspacePath), workspaceInputPath; path != exp {
 				t.Errorf(`expected input at %s, got %s`, exp, path)
 			}
 		})
@@ -141,18 +138,30 @@ func TestFindInput(t *testing.T) {
 				t.Fatalf("did not expect to find input.%s", tc.fileType)
 			}
 
-			createWithContent(t, tmpDir+"/workspace/foo/bar/input."+tc.fileType, tc.fileContent)
+			inputPath := filepath.Join(workspacePath, "foo", "bar", "input."+tc.fileType)
+
+			createWithContent(t, inputPath, tc.fileContent)
 
 			path, content := rio.FindInput(file, workspacePath)
-			if path != workspacePath+"/foo/bar/input."+tc.fileType || !maps.Equal(content, map[string]any{"x": true}) {
-				t.Errorf(`expected input {"x": true} at, got %s`, content)
+			if path != inputPath {
+				t.Errorf(`expected input at %s, got %s`, inputPath, path)
 			}
 
-			testutil.MustRemove(t, tmpDir+"/workspace/foo/bar/input."+tc.fileType)
-			createWithContent(t, tmpDir+"/workspace/input."+tc.fileType, tc.fileContent)
+			if !maps.Equal(content, map[string]any{"x": true}) {
+				t.Errorf(`expected input {"x": true}, got %s`, content)
+			}
+
+			testutil.MustRemove(t, inputPath)
+
+			workspaceInputPath := filepath.Join(workspacePath, "input."+tc.fileType)
+			createWithContent(t, workspaceInputPath, tc.fileContent)
 
 			path, content = rio.FindInput(file, workspacePath)
-			if path != workspacePath+"/input."+tc.fileType || !maps.Equal(content, map[string]any{"x": true}) {
+			if path != workspaceInputPath {
+				t.Errorf(`expected input at %s, got %s`, workspaceInputPath, path)
+			}
+
+			if !maps.Equal(content, map[string]any{"x": true}) {
 				t.Errorf(`expected input {"x": true} at, got %s`, content)
 			}
 		})
