@@ -3,7 +3,7 @@ package examples
 import (
 	"sync"
 
-	"github.com/styrainc/roast/pkg/encoding"
+	"github.com/open-policy-agent/regal/pkg/roast/encoding"
 
 	_ "embed"
 )
