@@ -6,7 +6,7 @@ import (
 	"github.com/open-policy-agent/opa/v1/ast"
 	"github.com/open-policy-agent/opa/v1/types"
 
-	"github.com/styrainc/regal/internal/testutil"
+	"github.com/open-policy-agent/regal/internal/testutil"
 )
 
 func TestCreateHoverContent(t *testing.T) {
@@ -49,8 +49,8 @@ func TestCreateHoverContent(t *testing.T) {
 		file := testutil.MustReadFile(t, c.testdata)
 		hoverContent := CreateHoverContent(c.builtin)
 
-		if string(file) != hoverContent {
-			t.Errorf("Expected %s, got %s", string(file), hoverContent)
+		if file != hoverContent {
+			t.Errorf("Expected %s, got %s", file, hoverContent)
 		}
 	}
 }
