@@ -3,7 +3,6 @@ package types
 import (
 	"encoding/json"
 
-	"github.com/open-policy-agent/regal/internal/lsp/types/completion"
 	"github.com/open-policy-agent/regal/internal/lsp/types/symbols"
 )
 
@@ -88,14 +87,17 @@ type (
 		DocumentSymbolProvider     bool                    `json:"documentSymbolProvider"`
 		WorkspaceSymbolProvider    bool                    `json:"workspaceSymbolProvider"`
 		DefinitionProvider         bool                    `json:"definitionProvider"`
+		SelectionRangeProvider     bool                    `json:"selectionRangeProvider"`
+		LinkedEditingRangeProvider bool                    `json:"linkedEditingRangeProvider"`
 	}
 
 	TextDocumentPositionParams struct {
 		TextDocument TextDocumentIdentifier `json:"textDocument"`
 		Position     Position               `json:"position"`
 	}
-	DefinitionParams        = TextDocumentPositionParams
-	TextDocumentHoverParams = TextDocumentPositionParams
+	DefinitionParams         = TextDocumentPositionParams
+	TextDocumentHoverParams  = TextDocumentPositionParams
+	LinkedEditingRangeParams = TextDocumentPositionParams
 
 	CompletionOptions struct {
 		CompletionItem    CompletionItemOptions `json:"completionItem"`
@@ -114,8 +116,8 @@ type (
 	}
 
 	CompletionContext struct {
-		TriggerCharacter string                 `json:"triggerCharacter"`
-		TriggerKind      completion.TriggerKind `json:"triggerKind"`
+		TriggerCharacter string `json:"triggerCharacter"`
+		TriggerKind      uint   `json:"triggerKind"`
 	}
 
 	CompletionList struct {
@@ -128,20 +130,11 @@ type (
 		Documentation   *MarkupContent              `json:"documentation,omitempty"`
 		TextEdit        *TextEdit                   `json:"textEdit,omitempty"`
 		InserTextFormat *uint                       `json:"insertTextFormat,omitempty"`
-
-		// Regal is used to store regal-specific metadata about the completion item.
-		// This is not part of the LSP spec, but used in the manager to post process
-		// items before returning them to the client.
-		Regal  *CompletionItemRegalMetadata `json:"_regal,omitempty"`
-		Label  string                       `json:"label"`
-		Detail string                       `json:"detail"`
-		// https://microsoft.github.io/language-server-protocol/specifications/lsp/3.17/specification/#completionItemKind
-		Kind      completion.ItemKind `json:"kind"`
-		Preselect bool                `json:"preselect"`
-	}
-
-	CompletionItemRegalMetadata struct {
-		Provider string `json:"provider"`
+		SortText        *string                     `json:"sortText,omitempty"`
+		Label           string                      `json:"label"`
+		Detail          string                      `json:"detail"`
+		Kind            uint                        `json:"kind"`
+		Preselect       bool                        `json:"preselect"`
 	}
 
 	CompletionItemLabelDetails struct {
@@ -208,6 +201,21 @@ type (
 		Kind  uint  `json:"kind"`
 	}
 
+	LinkedEditingRanges struct {
+		Ranges      []Range `json:"ranges"`
+		WordPattern *string `json:"wordPattern,omitempty"`
+	}
+
+	SelectionRangeParams struct {
+		TextDocument TextDocumentIdentifier `json:"textDocument"`
+		Positions    []Position             `json:"positions"`
+	}
+
+	SelectionRange struct {
+		Range  Range           `json:"range"`
+		Parent *SelectionRange `json:"parent,omitempty"`
+	}
+
 	ExecuteCommandOptions struct {
 		Commands []string `json:"commands"`
 	}
