@@ -1,6 +1,7 @@
 package util
 
 import (
+	"cmp"
 	"errors"
 	"fmt"
 	"math"
@@ -11,8 +12,8 @@ import (
 	"strings"
 )
 
-// NullToEmpty returns empty slice if provided slice is nil.
-func NullToEmpty[T any](a []T) []T {
+// NilSliceToEmpty returns empty slice if provided slice is nil.
+func NilSliceToEmpty[T any](a []T) []T {
 	if a == nil {
 		return []T{}
 	}
@@ -42,13 +43,6 @@ func SearchMap(object map[string]any, path ...string) (any, error) {
 	return current, nil
 }
 
-// Must0 an error (as commonly returned by Go functions) and panics if the error is not nil.
-func Must0(err error) {
-	if err != nil {
-		panic(err)
-	}
-}
-
 // Must takes a value and an error (as commonly returned by Go functions) and panics if the error is not nil.
 func Must[T any](v T, err error) T {
 	if err != nil {
@@ -120,7 +114,7 @@ func Filter[T any](s []T, f func(T) bool) []T {
 // FindClosestMatchingRoot finds the closest matching root for a given path.
 // If no matching root is found, an empty string is returned.
 func FindClosestMatchingRoot(path string, roots []string) string {
-	currentLongestSuffix, longestSuffixIndex := 0, -1
+	currentLongestPrefix, longestPrefixIndex := 0, -1
 
 	for i, root := range roots {
 		if root == path {
@@ -131,18 +125,17 @@ func FindClosestMatchingRoot(path string, roots []string) string {
 			continue
 		}
 
-		suffix := strings.TrimPrefix(root, path)
-		if len(suffix) > currentLongestSuffix {
-			currentLongestSuffix = len(suffix)
-			longestSuffixIndex = i
+		if len(root) > currentLongestPrefix {
+			currentLongestPrefix = len(root)
+			longestPrefixIndex = i
 		}
 	}
 
-	if longestSuffixIndex == -1 {
+	if longestPrefixIndex == -1 {
 		return ""
 	}
 
-	return roots[longestSuffixIndex]
+	return roots[longestPrefixIndex]
 }
 
 // FilepathJoiner returns a function that joins provided path with base path.
@@ -200,11 +193,7 @@ func EnsureSuffix(s, suf string) string {
 // IsAnyError checks if the provided error "Is" any of the provided errors.
 func IsAnyError(err error, errs ...error) bool {
 	if err != nil {
-		for _, e := range errs {
-			if errors.Is(err, e) {
-				return true
-			}
-		}
+		return slices.ContainsFunc(errs, Partial2(errors.Is, err))
 	}
 
 	return false
@@ -247,12 +236,11 @@ func FreePort(preferred ...int) (port int, err error) {
 		}
 		defer l.Close()
 
-		addr, ok := l.Addr().(*net.TCPAddr)
-		if !ok {
-			return 0, errors.New("failed to get port from listener")
+		if addr, ok := l.Addr().(*net.TCPAddr); ok {
+			return addr.Port, nil
 		}
 
-		return addr.Port, nil
+		return 0, errors.New("failed to get port from listener")
 	}
 
 	for _, p := range preferred {
@@ -271,10 +259,7 @@ func FreePort(preferred ...int) (port int, err error) {
 	return 0, fmt.Errorf("failed to find free port: %w", err)
 }
 
-func Pointer[T any](v T) *T {
-	return &v
-}
-
+// Wrap wraps a value and an error into a function that returns the value and error.
 func Wrap[T any](v T, err error) func(string) (T, error) {
 	if err != nil {
 		return func(msg string) (T, error) {
@@ -282,11 +267,12 @@ func Wrap[T any](v T, err error) func(string) (T, error) {
 		}
 	}
 
-	return func(_ string) (T, error) {
+	return func(string) (T, error) {
 		return v, nil
 	}
 }
 
+// WrapErr wraps an error with a message if the error is not nil.
 func WrapErr(err error, msg string) error {
 	if err == nil {
 		return nil
@@ -295,14 +281,52 @@ func WrapErr(err error, msg string) error {
 	return fmt.Errorf("%s: %w", msg, err)
 }
 
-func WithOpen[T any](path string, f func(*os.File) (T, error)) (T, error) {
-	file, err := os.Open(path)
-	if err != nil {
-		var zero T
-
-		return zero, fmt.Errorf("failed to open file '%s': %w", path, err)
+// SendToAll sends the provided value to all provided channels.
+func SendToAll[T any](val T, ch ...chan T) {
+	for _, c := range ch {
+		c <- val
 	}
-	defer file.Close()
+}
 
-	return f(file)
+// Pointer returns a pointer to the provided value.
+func Pointer[T any](v T) *T {
+	return &v
+}
+
+// Zero returns the zero value for any type T.
+func Zero[T any]() T {
+	var zero T
+
+	return zero
+}
+
+// AnySliceTo converts a slice of any to a slice of T, returning an error if any element cannot be casted.
+func AnySliceTo[T any](in []any) ([]T, error) {
+	out := make([]T, 0, len(in))
+
+	for _, item := range in {
+		casted, ok := item.(T)
+		if !ok {
+			return nil, fmt.Errorf("expected %T, got %T", casted, item)
+		}
+
+		out = append(out, casted)
+	}
+
+	return out, nil
+}
+
+// Sorted sorts s in place using slices.Sort and returns it
+// Can be convenient for use in return values, map definitions, chaining, etc.
+func Sorted[T cmp.Ordered](s []T) []T {
+	slices.Sort(s)
+
+	return s
+}
+
+// Reversed reverses s in place using slices.Reverse and returns it.
+func Reversed[T any](s []T) []T {
+	slices.Reverse(s)
+
+	return s
 }
