@@ -70,6 +70,7 @@ func (f *Fixer) RegisterFixes(fixes ...fixes.Fix) *Fixer {
 // Certain fixes may require the nearest root of the file to be known,
 // as fix operations could involve things like moving files, which
 // will be moved relative to their nearest root.
+// All roots should be absolute paths.
 func (f *Fixer) RegisterRoots(roots ...string) *Fixer {
 	f.registeredRoots = append(f.registeredRoots, roots...)
 
@@ -176,7 +177,7 @@ func (f *Fixer) applyLinterFixes(
 	fp fileprovider.FileProvider,
 	fixReport *Report,
 ) error {
-	enabledRules, err := l.DetermineEnabledRules(ctx)
+	enabledRules, _, err := l.DetermineEnabledRules(ctx)
 	if err != nil {
 		return fmt.Errorf("failed to determine enabled rules: %w", err)
 	}
