@@ -1,10 +1,11 @@
 package fixes
 
 import (
-	"strings"
+	"path/filepath"
 	"testing"
 
-	"github.com/styrainc/regal/pkg/config"
+	"github.com/open-policy-agent/regal/internal/testutil"
+	"github.com/open-policy-agent/regal/pkg/config"
 )
 
 func TestFixDirectoryPackageMismatch(t *testing.T) {
@@ -104,36 +105,20 @@ func TestFixDirectoryPackageMismatch(t *testing.T) {
 			t.Parallel()
 
 			dpm := DirectoryPackageMismatch{}
+			cnd := &FixCandidate{Filename: tc.name, Contents: tc.contents}
+			opt := &RuntimeOptions{BaseDir: tc.baseDir, Config: configWithExcludeTestSuffix(!tc.includeTestSuffix)}
 
-			fr, err := dpm.Fix(&FixCandidate{
-				Filename: tc.name,
-				Contents: tc.contents,
-			}, &RuntimeOptions{
-				BaseDir: tc.baseDir,
-				Config:  configWithExcludeTestSuffix(!tc.includeTestSuffix),
-			})
-			if err != nil {
-				if tc.wantErr == "" {
-					t.Errorf("failed to fix: %v", err)
-				}
-
-				if !strings.Contains(err.Error(), tc.wantErr) {
-					t.Errorf("expected error to contain %q, got %q", tc.wantErr, err.Error())
-				}
-			}
-
+			fr, err := dpm.Fix(cnd, opt)
 			if tc.wantErr != "" {
-				if err == nil {
-					t.Fatalf("expected error %q, got nil", tc.wantErr)
-				}
-
-				if !strings.Contains(err.Error(), tc.wantErr) {
-					t.Fatalf("expected error to contain %q, got %q", tc.wantErr, err.Error())
-				}
+				testutil.ErrMustContain(err, tc.wantErr)(t)
 
 				return
 			}
 
+			if err != nil {
+				t.Errorf("failed to fix: %v", err)
+			}
+
 			if len(fr) > 2 {
 				t.Fatal("0 or 1 fix result expected")
 			}
@@ -148,17 +133,17 @@ func TestFixDirectoryPackageMismatch(t *testing.T) {
 				t.Fatalf("expected %s, got %s", tc.expected.Contents, fr[0].Contents)
 			}
 
-			if fixResult.Rename == nil && tc.expected.Rename != nil {
-				t.Fatalf("expected rename to be non-nil, got nil")
-			}
-
 			if tc.expected.Rename != nil {
+				if fixResult.Rename == nil {
+					t.Fatal("expected rename to be non-nil, got nil")
+				}
+
 				if fixResult.Rename.FromPath != tc.expected.Rename.FromPath {
 					t.Fatalf("expected from path to be %s, got %s", tc.expected.Rename.FromPath, fixResult.Rename.FromPath)
 				}
 
-				if fixResult.Rename.ToPath != tc.expected.Rename.ToPath {
-					t.Fatalf("expected to path to be %s, got %s", tc.expected.Rename.ToPath, fixResult.Rename.ToPath)
+				if exp, got := fixResult.Rename.ToPath, filepath.FromSlash(tc.expected.Rename.ToPath); exp != got {
+					t.Fatalf("expected to path to be %s, got %s", exp, got)
 				}
 			}
 		})
@@ -166,16 +151,10 @@ func TestFixDirectoryPackageMismatch(t *testing.T) {
 }
 
 func configWithExcludeTestSuffix(exclude bool) *config.Config {
-	return &config.Config{
-		Rules: map[string]config.Category{
-			"idiomatic": {
-				"directory-package-mismatch": config.Rule{
-					Level: "ignore",
-					Extra: map[string]any{
-						"exclude-test-suffix": exclude,
-					},
-				},
-			},
+	return &config.Config{Rules: map[string]config.Category{"idiomatic": {
+		"directory-package-mismatch": config.Rule{
+			Level: "ignore",
+			Extra: map[string]any{"exclude-test-suffix": exclude},
 		},
-	}
+	}}}
 }
