@@ -6,7 +6,6 @@ import (
 	"fmt"
 	"io/fs"
 	"log"
-	"maps"
 	"os"
 	"path/filepath"
 	"slices"
@@ -21,6 +20,7 @@ import (
 	"github.com/open-policy-agent/opa/v1/metrics"
 	"github.com/open-policy-agent/opa/v1/profiler"
 	"github.com/open-policy-agent/opa/v1/rego"
+	"github.com/open-policy-agent/opa/v1/storage"
 	"github.com/open-policy-agent/opa/v1/topdown"
 	"github.com/open-policy-agent/opa/v1/topdown/print"
 	outil "github.com/open-policy-agent/opa/v1/util"
@@ -32,7 +32,6 @@ import (
 	"github.com/open-policy-agent/regal/pkg/builtins"
 	"github.com/open-policy-agent/regal/pkg/config"
 	"github.com/open-policy-agent/regal/pkg/report"
-	"github.com/open-policy-agent/regal/pkg/roast/rast"
 	"github.com/open-policy-agent/regal/pkg/roast/transform"
 	"github.com/open-policy-agent/regal/pkg/rules"
 )
@@ -64,7 +63,6 @@ type Linter struct {
 	enableAll            bool
 	profiling            bool
 	instrumentation      bool
-	hasCustomRules       bool
 	isPrepared           bool
 
 	preparedQuery *rego.PreparedEvalQuery
@@ -72,19 +70,9 @@ type Linter struct {
 
 var (
 	lintQueryStr         = "lint := data.regal.main.lint"
-	enabledRulesQueryStr = `[rule |
-		data.regal.rules[cat][rule]
-		object.get(data.regal.rules[cat][rule], "notices", set()) == set()
-		not data.regal.config.ignored_rule(cat, rule)
-	]`
-	enabledAggregateRulesQueryStr = `[rule |
-		data.regal.rules[cat][rule].aggregate
-		not data.regal.config.ignored_rule(cat, rule)
-	]`
-
-	lintQuery                  = ast.MustParseBody(lintQueryStr)
-	enabledRulesQuery          = ast.MustParseBody(enabledRulesQueryStr)
-	enabledAggregateRulesQuery = ast.MustParseBody(enabledAggregateRulesQueryStr)
+	enabledRulesQueryStr = "enabled := data.regal.main.enabled_rules"
+	lintQuery            = ast.MustParseBody(lintQueryStr)
+	enabledRulesQuery    = ast.MustParseBody(enabledRulesQueryStr)
 )
 
 func init() {
@@ -96,7 +84,7 @@ func init() {
 // NewLinter creates a new Regal linter.
 func NewLinter() Linter {
 	return Linter{
-		ruleBundles: []*bundle.Bundle{rbundle.LoadedBundle()},
+		ruleBundles: []*bundle.Bundle{rbundle.Loaded()},
 	}
 }
 
@@ -124,64 +112,43 @@ func (l Linter) WithInputModules(input *rules.Input) Linter {
 // WithAddedBundle adds a bundle of rules and data to include in evaluation.
 func (l Linter) WithAddedBundle(b *bundle.Bundle) Linter {
 	l.ruleBundles = append(l.ruleBundles, b)
-	l.isPrepared = false
 
-	return l
+	return l.notPrepared()
 }
 
 // WithCustomRules adds custom rules for evaluation, from the Rego (and data) files provided at paths.
 func (l Linter) WithCustomRules(paths []string) Linter {
 	for _, path := range paths {
-		stat, err := os.Stat(path)
-		if err != nil {
-			l.customRuleError = fmt.Errorf("failed to stat custom rule file %s: %w", path, err)
-
-			return l
-		}
-
-		if stat.IsDir() {
+		if rio.IsDir(path) {
 			l = l.WithCustomRulesFromFS(os.DirFS(path), ".")
 		} else {
 			contents, err := os.ReadFile(path)
 			if err != nil {
 				l.customRuleError = fmt.Errorf("failed to read custom rule file %s: %w", path, err)
 
-				return l
+				return l.notPrepared()
 			}
 
-			l = l.WithCustomRulesFromFS(fstest.MapFS{
-				filepath.Base(path): &fstest.MapFile{Data: contents},
-			}, ".")
+			l = l.WithCustomRulesFromFS(fstest.MapFS{filepath.Base(path): &fstest.MapFile{Data: contents}}, ".")
 		}
 	}
 
-	l.isPrepared = false
-
-	return l
+	return l.notPrepared()
 }
 
 // WithCustomRulesFromFS adds custom rules for evaluation from a filesystem implementing the fs.FS interface.
 // A root path within the filesystem must also be specified. Note, _test.rego files will be ignored.
 func (l Linter) WithCustomRulesFromFS(f fs.FS, rootPath string) Linter {
-	if f == nil {
-		return l
+	if f != nil {
+		modules, err := rio.ModulesFromCustomRuleFS(f, rootPath)
+		if err != nil {
+			l.customRuleError = err
+		} else {
+			l.customRuleModules = append(l.customRuleModules, outil.Values(modules)...)
+		}
 	}
 
-	l.hasCustomRules = true
-	l.isPrepared = false
-
-	modules, err := rio.ModulesFromCustomRuleFS(f, rootPath)
-	if err != nil {
-		l.customRuleError = err
-
-		return l
-	}
-
-	for _, m := range modules {
-		l.customRuleModules = append(l.customRuleModules, m)
-	}
-
-	return l
+	return l.notPrepared()
 }
 
 // WithDebugMode enables debug mode.
@@ -194,65 +161,57 @@ func (l Linter) WithDebugMode(debugMode bool) Linter {
 // WithUserConfig provides config overrides set by the user.
 func (l Linter) WithUserConfig(cfg config.Config) Linter {
 	l.userConfig = &cfg
-	l.isPrepared = false
 
-	return l
+	return l.notPrepared()
 }
 
 // WithDisabledRules disables provided rules. This overrides configuration provided in file.
 func (l Linter) WithDisabledRules(disable ...string) Linter {
 	l.disable = disable
-	l.isPrepared = false
 
-	return l
+	return l.notPrepared()
 }
 
 // WithDisableAll disables all rules when set to true. This overrides configuration provided in file.
 func (l Linter) WithDisableAll(disableAll bool) Linter {
 	l.disableAll = disableAll
-	l.isPrepared = false
 
-	return l
+	return l.notPrepared()
 }
 
 // WithDisabledCategories disables provided categories of rules. This overrides configuration provided in file.
 func (l Linter) WithDisabledCategories(disableCategory ...string) Linter {
 	l.disableCategory = disableCategory
-	l.isPrepared = false
 
-	return l
+	return l.notPrepared()
 }
 
 // WithEnabledRules enables provided rules. This overrides configuration provided in file.
 func (l Linter) WithEnabledRules(enable ...string) Linter {
 	l.enable = enable
-	l.isPrepared = false
 
-	return l
+	return l.notPrepared()
 }
 
 // WithEnableAll enables all rules when set to true. This overrides configuration provided in file.
 func (l Linter) WithEnableAll(enableAll bool) Linter {
 	l.enableAll = enableAll
-	l.isPrepared = false
 
-	return l
+	return l.notPrepared()
 }
 
 // WithEnabledCategories enables provided categories of rules. This overrides configuration provided in file.
 func (l Linter) WithEnabledCategories(enableCategory ...string) Linter {
 	l.enableCategory = enableCategory
-	l.isPrepared = false
 
-	return l
+	return l.notPrepared()
 }
 
 // WithIgnore excludes files matching patterns. This overrides configuration provided in file.
 func (l Linter) WithIgnore(ignore []string) Linter {
 	l.ignoreFiles = ignore
-	l.isPrepared = false
 
-	return l
+	return l.notPrepared()
 }
 
 // WithMetrics enables metrics collection.
@@ -287,9 +246,8 @@ func (l Linter) WithInstrumentation(enabled bool) Linter {
 // referenced in the linter configuration with absolute file paths or URIs.
 func (l Linter) WithPathPrefix(pathPrefix string) Linter {
 	l.pathPrefix = pathPrefix
-	l.isPrepared = false
 
-	return l
+	return l.notPrepared()
 }
 
 // WithExportAggregates enables the setting of intermediate aggregate data
@@ -333,6 +291,9 @@ func (l Linter) WithBaseCache(baseCache topdown.BaseCache) Linter {
 // are very likely to change in the future, and this method should not yet be
 // relied on by external clients.
 func (l Linter) Prepare(ctx context.Context) (Linter, error) {
+	l.startTimer(regalmetrics.RegalPrepare)
+	defer l.stopTimer(regalmetrics.RegalPrepare)
+
 	conf, err := l.GetConfig()
 	if err != nil {
 		return l, fmt.Errorf("failed to merge config: %w", err)
@@ -345,8 +306,7 @@ func (l Linter) Prepare(ctx context.Context) (Linter, error) {
 	l.combinedCfg = conf
 	l.dataBundle = l.createDataBundle(*conf)
 
-	l.preparedQuery, err = l.prepareQuery(ctx)
-	if err != nil {
+	if l.preparedQuery, err = l.prepareQuery(ctx); err != nil {
 		return l, fmt.Errorf("failed to prepare query: %w", err)
 	}
 
@@ -370,13 +330,9 @@ func (l Linter) MustPrepare(ctx context.Context) Linter {
 func (l Linter) Lint(ctx context.Context) (report.Report, error) {
 	l.startTimer(regalmetrics.RegalLint)
 
-	finalReport := report.Report{}
-
 	if !l.isPrepared {
 		var err error
-
-		l, err = l.Prepare(ctx)
-		if err != nil {
+		if l, err = l.Prepare(ctx); err != nil {
 			return report.Report{}, fmt.Errorf("failed to prepare linter: %w", err)
 		}
 	}
@@ -442,17 +398,15 @@ func (l Linter) Lint(ctx context.Context) (report.Report, error) {
 		return report.Report{}, fmt.Errorf("failed to lint using Rego rules: %w", err)
 	}
 
-	finalReport.Violations = append(finalReport.Violations, regoReport.Violations...)
-
+	slices.SortFunc(regoReport.Notices, func(a, b report.Notice) int {
+		return strings.Compare(a.Title, b.Title)
+	})
+	regoReport.Notices = slices.Compact(regoReport.Notices)
 	rulesSkippedCounter := 0
 
 	for _, notice := range regoReport.Notices {
-		if !slices.Contains(finalReport.Notices, notice) {
-			finalReport.Notices = append(finalReport.Notices, notice)
-
-			if notice.Severity != "none" {
-				rulesSkippedCounter++
-			}
+		if notice.Severity != "none" {
+			rulesSkippedCounter++
 		}
 	}
 
@@ -474,93 +428,67 @@ func (l Linter) Lint(ctx context.Context) (report.Report, error) {
 			return report.Report{}, fmt.Errorf("failed to lint using Rego aggregate rules: %w", err)
 		}
 
-		finalReport.Violations = append(finalReport.Violations, aggregateReport.Violations...)
+		regoReport.Violations = append(regoReport.Violations, aggregateReport.Violations...)
 
 		if l.profiling {
-			finalReport.AggregateProfile = aggregateReport.AggregateProfile
+			regoReport.AggregateProfile = aggregateReport.AggregateProfile
 		}
 	}
 
-	finalReport.Summary = report.Summary{
+	regoReport.Summary = report.Summary{
 		FilesScanned:  len(input.FileNames),
-		FilesFailed:   len(finalReport.ViolationsFileCount()),
+		FilesFailed:   len(regoReport.ViolationsFileCount()),
 		RulesSkipped:  rulesSkippedCounter,
-		NumViolations: len(finalReport.Violations),
+		NumViolations: len(regoReport.Violations),
 	}
 
-	if l.exportAggregates {
-		finalReport.Aggregates = make(map[string][]report.Aggregate, len(regoReport.Aggregates))
-		for k, aggregates := range regoReport.Aggregates {
-			finalReport.Aggregates[k] = append(finalReport.Aggregates[k], aggregates...)
-		}
+	if !l.exportAggregates {
+		regoReport.Aggregates = nil
 	}
 
+	l.stopTimer(regalmetrics.RegalLint)
+
 	if l.metrics != nil {
-		l.metrics.Timer(regalmetrics.RegalLint).Stop()
-
-		finalReport.Metrics = l.metrics.All()
+		regoReport.Metrics = l.metrics.All()
 	}
 
-	if l.profiling {
-		if finalReport.AggregateProfile == nil {
-			finalReport.AggregateProfile = regoReport.AggregateProfile
-		} else {
-			maps.Copy(finalReport.AggregateProfile, regoReport.AggregateProfile)
-		}
-
-		finalReport.AggregateProfileToSortedProfile(10)
-		finalReport.AggregateProfile = nil
+	if l.profiling && regoReport.AggregateProfile != nil {
+		regoReport.AggregateProfileToSortedProfile(10)
+		regoReport.AggregateProfile = nil
 	}
 
-	return finalReport, nil
+	return regoReport, nil
 }
 
 // DetermineEnabledRules returns the list of rules that are enabled based on
 // the supplied configuration. This makes use of the linter rule settings
 // to produce a single list of the rules that are to be run on this linter
 // instance.
-func (l Linter) DetermineEnabledRules(ctx context.Context) ([]string, error) {
+func (l Linter) DetermineEnabledRules(ctx context.Context) ([]string, []string, error) {
 	conf, err := l.GetConfig()
 	if err != nil {
-		return []string{}, fmt.Errorf("failed to merge config: %w", err)
+		return nil, nil, fmt.Errorf("failed to merge config: %w", err)
 	}
 
 	l.dataBundle = l.createDataBundle(*conf)
 
 	regoArgs, err := l.prepareRegoArgs(enabledRulesQuery)
 	if err != nil {
-		return nil, fmt.Errorf("failed preparing query %s: %w", enabledRulesQueryStr, err)
+		return nil, nil, fmt.Errorf("failed preparing query %s: %w", enabledRulesQueryStr, err)
 	}
 
+	var compiler *ast.Compiler
+
+	regoArgs = append(regoArgs, rego.CompilerHook(func(c *ast.Compiler) {
+		compiler = c
+	}))
+
 	rs, err := rego.New(regoArgs...).Eval(ctx)
 	if err != nil {
-		return nil, fmt.Errorf("failed evaluating query %s: %w", enabledRulesQueryStr, err)
+		return nil, nil, fmt.Errorf("failed evaluating query %s: %w", enabledRulesQueryStr, err)
 	}
 
-	return getEnabledRules(rs)
-}
-
-// DetermineEnabledAggregateRules returns the list of aggregate rules that are
-// enabled based on the configuration.
-func (l Linter) DetermineEnabledAggregateRules(ctx context.Context) ([]string, error) {
-	conf, err := l.GetConfig()
-	if err != nil {
-		return []string{}, fmt.Errorf("failed to merge config: %w", err)
-	}
-
-	l.dataBundle = l.createDataBundle(*conf)
-
-	regoArgs, err := l.prepareRegoArgs(enabledAggregateRulesQuery)
-	if err != nil {
-		return nil, fmt.Errorf("failed preparing query %s: %w", enabledAggregateRulesQueryStr, err)
-	}
-
-	rs, err := rego.New(regoArgs...).Eval(ctx)
-	if err != nil {
-		return nil, fmt.Errorf("failed evaluating query %s: %w", enabledAggregateRulesQueryStr, err)
-	}
-
-	return getEnabledRules(rs)
+	return getEnabledRules(rs, compiler)
 }
 
 // GetConfig returns the final configuration for the linter, i.e. Regal's default
@@ -570,7 +498,7 @@ func (l Linter) GetConfig() (*config.Config, error) {
 		return l.combinedCfg, nil
 	}
 
-	mergedConf, err := config.WithDefaultsFromBundle(rbundle.LoadedBundle(), l.userConfig)
+	mergedConf, err := config.WithDefaultsFromBundle(rbundle.Loaded(), l.userConfig)
 	if err != nil {
 		return nil, fmt.Errorf("failed to read provided config: %w", err)
 	}
@@ -601,6 +529,12 @@ func (l Linter) prepareQuery(ctx context.Context) (*rego.PreparedEvalQuery, erro
 	return &pq, nil
 }
 
+func (l Linter) notPrepared() Linter {
+	l.isPrepared = false
+
+	return l
+}
+
 func (l Linter) validate(conf *config.Config) error {
 	if len(l.inputPaths) == 0 && l.inputModules == nil && len(l.overriddenAggregates) == 0 {
 		return errors.New("nothing provided to lint")
@@ -616,7 +550,7 @@ func (l Linter) validate(conf *config.Config) error {
 	// Add all built-in rules
 	for _, b := range l.ruleBundles {
 		for _, module := range b.Modules {
-			parts := rast.UnquotedPath(module.Parsed.Package.Path)
+			parts, _ := storage.NewPathForRef(module.Parsed.Package.Path)
 			// 1     2     3   4
 			// regal.rules.cat.rule
 			if len(parts) != 4 {
@@ -630,7 +564,7 @@ func (l Linter) validate(conf *config.Config) error {
 
 	// Add any custom rules
 	for _, module := range l.customRuleModules {
-		parts := rast.UnquotedPath(module.Package.Path)
+		parts, _ := storage.NewPathForRef(module.Package.Path)
 		// 1      2     3     4   5
 		// custom.regal.rules.cat.rule
 		if len(parts) != 5 {
@@ -668,41 +602,53 @@ func (l Linter) validate(conf *config.Config) error {
 	return nil
 }
 
-func getEnabledRules(rs rego.ResultSet) ([]string, error) {
-	if len(rs) != 1 || len(rs[0].Expressions) != 1 {
-		return nil, fmt.Errorf("expected exactly one expression, got %d", len(rs[0].Expressions))
+func getEnabledRules(rs rego.ResultSet, c *ast.Compiler) (regular, aggregate []string, err error) {
+	if len(rs) == 0 {
+		return nil, nil, errors.New("expected result set of at least one result, got none")
 	}
 
-	list, ok := rs[0].Expressions[0].Value.([]any)
+	enabled, ok := rs[0].Bindings["enabled"].(map[string]any)
 	if !ok {
-		return nil, fmt.Errorf("expected list, got %T", rs[0].Expressions[0].Value)
+		return nil, nil, errors.New("expected list of enabled rules, didn't get it")
 	}
 
-	enabledRules := make([]string, 0, len(list))
+	// Since we currently have no reliable way to determine whether a rule is an aggregate
+	// rule or not in Rego without actually evaluating it, we query the comiler for this
+	// information for each rule in the result. Long term, we should figure out the best way
+	// to do this in Rego only.
+	ref := ast.DefaultRootRef.Extend(ast.MustParseRef("regal.rules.category.title.aggregate"))
 
-	for _, item := range list {
-		rule, ok := item.(string)
+	for category, rules := range enabled {
+		categoryRules, ok := rules.(map[string]any)
 		if !ok {
-			return nil, fmt.Errorf("expected string, got %T", item)
+			return nil, nil, fmt.Errorf("expected list of enabled rules for category %s, didn't get it", category)
 		}
 
-		enabledRules = append(enabledRules, rule)
+		ref[3] = ast.InternedTerm(category)
+
+		for title := range categoryRules {
+			ref[4] = ast.InternedTerm(title)
+
+			if rules := c.GetRulesExact(ref); len(rules) == 0 {
+				regular = append(regular, title)
+			} else {
+				aggregate = append(aggregate, title)
+			}
+		}
 	}
 
-	slices.Sort(enabledRules)
-
-	return enabledRules, nil
+	return util.Sorted(regular), util.Sorted(aggregate), nil
 }
 
 func (l Linter) createDataBundle(conf config.Config) *bundle.Bundle {
 	params := map[string]any{
 		"disable_all":      l.disableAll,
-		"disable_category": util.NullToEmpty(l.disableCategory),
-		"disable":          util.NullToEmpty(l.disable),
+		"disable_category": util.NilSliceToEmpty(l.disableCategory),
+		"disable":          util.NilSliceToEmpty(l.disable),
 		"enable_all":       l.enableAll,
-		"enable_category":  util.NullToEmpty(l.enableCategory),
-		"enable":           util.NullToEmpty(l.enable),
-		"ignore_files":     util.NullToEmpty(l.ignoreFiles),
+		"enable_category":  util.NilSliceToEmpty(l.enableCategory),
+		"enable":           util.NilSliceToEmpty(l.enable),
+		"ignore_files":     util.NilSliceToEmpty(l.ignoreFiles),
 	}
 
 	return &bundle.Bundle{
@@ -724,6 +670,10 @@ func (l Linter) createDataBundle(conf config.Config) *bundle.Bundle {
 }
 
 func (l Linter) prepareRegoArgs(query ast.Body) ([]func(*rego.Rego), error) {
+	if l.customRuleError != nil {
+		return nil, fmt.Errorf("failed to load custom rules: %w", l.customRuleError)
+	}
+
 	regoArgs := append([]func(*rego.Rego){
 		rego.StoreReadAST(true),
 		rego.Metrics(l.metrics),
@@ -743,14 +693,8 @@ func (l Linter) prepareRegoArgs(query ast.Body) ([]func(*rego.Rego), error) {
 		regoArgs = append(regoArgs, rego.ParsedBundle("internal", l.dataBundle))
 	}
 
-	if l.hasCustomRules {
-		if l.customRuleError != nil {
-			return nil, fmt.Errorf("failed to load custom rules: %w", l.customRuleError)
-		}
-
-		for _, m := range l.customRuleModules {
-			regoArgs = append(regoArgs, rego.ParsedModule(m))
-		}
+	for _, m := range l.customRuleModules {
+		regoArgs = append(regoArgs, rego.ParsedModule(m))
 	}
 
 	if l.ruleBundles != nil {
@@ -774,23 +718,20 @@ func (l Linter) lint(ctx context.Context, input rules.Input) (report.Report, err
 	ctx, cancel := context.WithCancel(ctx)
 	defer cancel()
 
-	regoReport := report.Report{}
-	regoReport.Aggregates = make(map[string][]report.Aggregate, len(input.FileNames))
-	regoReport.IgnoreDirectives = make(map[string]map[string][]string, len(input.FileNames))
-
-	operationCollect := len(input.FileNames) > 1 || l.useCollectQuery
+	numFiles := len(input.FileNames)
+	operationCollect := numFiles > 1 || l.useCollectQuery
 
 	var wg sync.WaitGroup
 
-	var mu sync.Mutex
-
 	// the error channel is buffered to prevent blocking
 	// caused by the context cancellation happening before
 	// errors are sent and the per-file goroutines can exit.
-	errCh := make(chan error, len(input.FileNames))
+	errCh := make(chan error, numFiles)
 	doneCh := make(chan bool)
 
-	for _, name := range input.FileNames {
+	results := make([]report.Report, numFiles)
+
+	for i, name := range input.FileNames {
 		wg.Add(1)
 
 		go func(name string) {
@@ -803,10 +744,7 @@ func (l Linter) lint(ctx context.Context, input rules.Input) (report.Report, err
 				return
 			}
 
-			evalArgs := []rego.EvalOption{
-				rego.EvalParsedInput(inputValue),
-				rego.EvalInstrument(l.instrumentation),
-			}
+			evalArgs := []rego.EvalOption{rego.EvalParsedInput(inputValue), rego.EvalInstrument(l.instrumentation)}
 
 			if l.baseCache != nil {
 				evalArgs = append(evalArgs, rego.EvalBaseCache(l.baseCache))
@@ -848,36 +786,7 @@ func (l Linter) lint(ctx context.Context, input rules.Input) (report.Report, err
 				}
 			}
 
-			mu.Lock()
-			defer mu.Unlock()
-
-			regoReport.Violations = append(regoReport.Violations, result.Violations...)
-			regoReport.Notices = append(regoReport.Notices, result.Notices...)
-
-			for k := range result.Aggregates {
-				// Custom aggregate rules that have been invoked but not returned any data
-				// will return an empty map to signal that they have been called, and that
-				// the aggregate report for this rule should be invoked even when no data
-				// was aggregated. This because the absence of data is exactly what some rules
-				// will want to report on.
-				for _, agg := range result.Aggregates[k] {
-					if len(agg) == 0 {
-						if _, ok := regoReport.Aggregates[k]; !ok {
-							regoReport.Aggregates[k] = make([]report.Aggregate, 0)
-						}
-					} else {
-						regoReport.Aggregates[k] = append(regoReport.Aggregates[k], agg)
-					}
-				}
-			}
-
-			for k := range result.IgnoreDirectives {
-				regoReport.IgnoreDirectives[k] = result.IgnoreDirectives[k]
-			}
-
-			if l.profiling {
-				regoReport.AddProfileEntries(result.AggregateProfile)
-			}
+			results[i] = result
 		}(name)
 	}
 
@@ -893,6 +802,44 @@ func (l Linter) lint(ctx context.Context, input rules.Input) (report.Report, err
 	case err := <-errCh:
 		return report.Report{}, fmt.Errorf("error encountered in rule evaluation %w", err)
 	case <-doneCh:
+		l.startTimer(regalmetrics.RegalMergeReport)
+		defer l.stopTimer(regalmetrics.RegalMergeReport)
+
+		regoReport := report.Report{
+			Aggregates:       make(map[string][]report.Aggregate, numFiles),
+			IgnoreDirectives: make(map[string]map[string][]string, numFiles),
+		}
+
+		for i := range results {
+			regoReport.Violations = append(regoReport.Violations, results[i].Violations...)
+			regoReport.Notices = append(regoReport.Notices, results[i].Notices...)
+
+			for k := range results[i].Aggregates {
+				// Custom aggregate rules that have been invoked but not returned any data
+				// will return an empty map to signal that they have been called, and that
+				// the aggregate report for this rule should be invoked even when no data
+				// was aggregated. This because the absence of data is exactly what some rules
+				// will want to report on.
+				for _, agg := range results[i].Aggregates[k] {
+					if len(agg) == 0 {
+						if _, ok := regoReport.Aggregates[k]; !ok {
+							regoReport.Aggregates[k] = make([]report.Aggregate, 0)
+						}
+					} else {
+						regoReport.Aggregates[k] = append(regoReport.Aggregates[k], agg)
+					}
+				}
+			}
+
+			for k := range results[i].IgnoreDirectives {
+				regoReport.IgnoreDirectives[k] = results[i].IgnoreDirectives[k]
+			}
+
+			if l.profiling {
+				regoReport.AddProfileEntries(results[i].AggregateProfile)
+			}
+		}
+
 		return regoReport, nil
 	}
 }
@@ -908,27 +855,22 @@ func (l Linter) lintWithAggregateRules(
 	ctx, cancel := context.WithCancel(ctx)
 	defer cancel()
 
-	input := map[string]any{
-		// This will be replaced by the routing policy to provide each
-		// aggregate rule only the aggregated data from the same rule
-		"aggregates_internal": aggregates,
-		// There is no file provided in input here, but we'll provide *something* for
-		// consistency, and to avoid silently failing with undefined should someone
-		// refer to input.regal in an aggregate_report rule
-		"ignore_directives": ignoreDirectives,
-		"regal": map[string]any{
-			"operations": []string{"aggregate"},
-			"file": map[string]any{
-				"name":  "__aggregate_report__",
-				"lines": []string{},
-			},
-		},
-	}
+	regal := ast.ObjectTerm(
+		ast.Item(ast.InternedTerm("operations"), ast.ArrayTerm(ast.InternedTerm("aggregate"))),
+		ast.Item(ast.InternedTerm("file"), ast.ObjectTerm(
+			ast.Item(ast.InternedTerm("name"), ast.InternedTerm("__aggregate_report__")),
+			ast.Item(ast.InternedTerm("lines"), ast.InternedEmptyArray),
+		)),
+	)
 
-	inputValue, err := transform.ToOPAInputValue(input)
-	if err != nil {
-		return report.Report{}, fmt.Errorf("failed to transform input value: %w", err)
-	}
+	aggParsed, _ := transform.ToOPAInputValue(aggregates)
+	dirParsed, _ := transform.ToOPAInputValue(ignoreDirectives)
+
+	inputValue := ast.NewObject(
+		ast.Item(ast.InternedTerm("aggregates_internal"), ast.NewTerm(aggParsed)),
+		ast.Item(ast.InternedTerm("ignore_directives"), ast.NewTerm(dirParsed)),
+		ast.Item(ast.InternedTerm("regal"), regal),
+	)
 
 	evalArgs := []rego.EvalOption{
 		rego.EvalParsedInput(inputValue),
