@@ -5,16 +5,15 @@ import (
 	"fmt"
 	"io"
 	"os"
-	"slices"
 	"strings"
 
 	"github.com/fatih/color"
 	"github.com/jstemmer/go-junit-report/v2/junit"
 	"github.com/olekukonko/tablewriter"
+	"github.com/olekukonko/tablewriter/renderer"
+	"github.com/olekukonko/tablewriter/tw"
 	"github.com/owenrumney/go-sarif/v2/sarif"
 
-	outil "github.com/open-policy-agent/opa/v1/util"
-
 	"github.com/open-policy-agent/regal/internal/mode"
 	"github.com/open-policy-agent/regal/internal/novelty"
 	"github.com/open-policy-agent/regal/internal/util"
@@ -139,12 +138,7 @@ func (tr PrettyReporter) Publish(_ context.Context, r report.Report) error {
 	}
 
 	if r.Summary.RulesSkipped > 0 {
-		footer += fmt.Sprintf(
-			" %d %s skipped:\n",
-			r.Summary.RulesSkipped,
-			pluralize("rule", r.Summary.RulesSkipped),
-		)
-
+		footer += fmt.Sprintf(" %d %s skipped:\n", r.Summary.RulesSkipped, pluralize("rule", r.Summary.RulesSkipped))
 		for _, notice := range r.Notices {
 			if notice.Severity != "none" {
 				footer += fmt.Sprintf("- %s: %s\n", notice.Title, notice.Description)
@@ -152,7 +146,7 @@ func (tr PrettyReporter) Publish(_ context.Context, r report.Report) error {
 		}
 	}
 
-	_, err := fmt.Fprint(tr.out, table+footer+"\n")
+	_, err := fmt.Fprintln(tr.out, table+footer)
 	if err != nil {
 		return fmt.Errorf("failed to write report: %w", err)
 	}
@@ -172,9 +166,7 @@ func (tr PrettyReporter) Publish(_ context.Context, r report.Report) error {
 	}
 
 	if fixableViolations.Size() > 0 {
-		violationKeys := fixableViolations.Items()
-		slices.Sort(violationKeys)
-
+		violationKeys := util.Sorted(fixableViolations.Items())
 		_, err = fmt.Fprintf(
 			tr.out,
 			`
@@ -203,17 +195,16 @@ func (tr FestiveReporter) Publish(ctx context.Context, r report.Report) error {
 
 func buildPrettyViolationsTable(violations []report.Violation) string {
 	sb := &strings.Builder{}
-	table := tablewriter.NewWriter(sb)
-
-	table.SetNoWhiteSpace(true)
-	table.SetTablePadding("\t")
-	table.SetAlignment(tablewriter.ALIGN_LEFT)
-	table.SetCenterSeparator("")
-	table.SetColumnSeparator("")
-	table.SetRowSeparator("")
-	table.SetHeaderLine(false)
-	table.SetBorder(false)
-	table.SetAutoWrapText(false)
+	table := tablewriter.NewTable(sb, tablewriter.WithConfig(tablewriter.Config{
+		Row: tw.CellConfig{
+			Padding: tw.CellPadding{PerColumn: []tw.Padding{{Right: " "}, tw.PaddingDefault}},
+		},
+	}), tablewriter.WithRenderer(renderer.NewBlueprint(tw.Rendition{
+		Borders: tw.BorderNone,
+		Settings: tw.Settings{
+			Separators: tw.Separators{BetweenRows: tw.Off, BetweenColumns: tw.Off},
+		},
+	})))
 
 	numViolations := len(violations)
 
@@ -280,13 +271,15 @@ func (tr CompactReporter) Publish(_ context.Context, r report.Report) error {
 	}
 
 	sb := &strings.Builder{}
-	table := tablewriter.NewWriter(sb)
+	table := tablewriter.NewTable(sb, tablewriter.WithConfig(tablewriter.Config{
+		Row: tw.CellConfig{
+			Formatting:   tw.CellFormatting{AutoWrap: tw.WrapNormal},
+			Alignment:    tw.CellAlignment{Global: tw.AlignLeft},
+			ColMaxWidths: tw.CellWidth{Global: 80},
+		},
+	}))
 
-	table.SetHeader([]string{"Location", "Description"})
-	table.SetAutoFormatHeaders(false)
-
-	table.SetColWidth(80)
-	table.SetAutoWrapText(true)
+	table.Header([]string{"Location", "Description"})
 
 	for i := range r.Violations {
 		table.Append([]string{r.Violations[i].Location.String(), r.Violations[i].Description})
@@ -305,18 +298,12 @@ func (tr CompactReporter) Publish(_ context.Context, r report.Report) error {
 
 // Publish prints a JSON report to the configured output.
 func (tr JSONReporter) Publish(_ context.Context, r report.Report) error {
-	if r.Violations == nil {
-		r.Violations = []report.Violation{}
-	}
+	r.Violations = util.NilSliceToEmpty(r.Violations)
 
-	bs, err := encoding.JSON().MarshalIndent(r, "", "  ")
-	if err != nil {
-		return fmt.Errorf("json marshalling of report failed: %w", err)
-	}
+	enc := encoding.JSON().NewEncoder(tr.out)
+	enc.SetIndent("", "  ")
 
-	_, err = fmt.Fprintln(tr.out, outil.ByteSliceToString(bs))
-
-	return err
+	return enc.Encode(r)
 }
 
 // Publish first prints the pretty formatted report to console for easy access in the logs. It then goes on
@@ -327,7 +314,7 @@ func (tr GitHubReporter) Publish(ctx context.Context, r report.Report) error {
 		return err
 	}
 
-	r.Violations = util.NullToEmpty(r.Violations)
+	r.Violations = util.NilSliceToEmpty(r.Violations)
 
 	for _, violation := range r.Violations { //nolint:gocritic
 		if _, err := fmt.Fprintf(tr.out,
@@ -384,7 +371,7 @@ func (tr SarifReporter) Publish(_ context.Context, r report.Report) error {
 		return err
 	}
 
-	run := sarif.NewRunWithInformationURI("Regal", "https://docs.styra.com/regal")
+	run := sarif.NewRunWithInformationURI("Regal", "https://www.openpolicyagent.org/projects/regal")
 
 	for _, violation := range r.Violations { //nolint:gocritic
 		pb := sarif.NewPropertyBag()
@@ -432,10 +419,7 @@ func getLocation(violation report.Violation) *sarif.Location {
 	physicalLocation := sarif.NewPhysicalLocation().
 		WithArtifactLocation(sarif.NewSimpleArtifactLocation(violation.Location.File))
 
-	region := sarif.NewRegion().
-		WithStartLine(violation.Location.Row).
-		WithStartColumn(violation.Location.Column)
-
+	region := sarif.NewRegion().WithStartLine(violation.Location.Row).WithStartColumn(violation.Location.Column)
 	if violation.Location.End != nil {
 		region = region.WithEndLine(violation.Location.End.Row).WithEndColumn(violation.Location.End.Column)
 	}
@@ -468,9 +452,7 @@ func getUniqueViolationURLs(violations []report.Violation) map[string]string {
 
 // Publish prints a JUnit XML report to the configured output.
 func (tr JUnitReporter) Publish(_ context.Context, r report.Report) error {
-	testSuites := junit.Testsuites{
-		Name: "regal",
-	}
+	testSuites := junit.Testsuites{Name: "regal"}
 
 	// group by file & sort by file
 	files := make([]string, 0)
@@ -481,12 +463,8 @@ func (tr JUnitReporter) Publish(_ context.Context, r report.Report) error {
 		violationsPerFile[violation.Location.File] = append(violationsPerFile[violation.Location.File], violation)
 	}
 
-	slices.Sort(files)
-
-	for _, file := range files {
-		testsuite := junit.Testsuite{
-			Name: file,
-		}
+	for _, file := range util.Sorted(files) {
+		testsuite := junit.Testsuite{Name: file}
 
 		for _, violation := range violationsPerFile[file] { //nolint:gocritic
 			text := ""
